@@ -1,5 +1,5 @@
 /*
- * Version:     $Id: ipv6calc.h,v 0.18 2001/03/14 $
+ * Version:     $Id: ipv6calc.h,v 0.20 2001/03/15 $
  *
  * Author:      Peter Bieringer <pb@bieringer.de>
  *
@@ -7,7 +7,7 @@
 
 /* global definitions */
 #define PROGRAM_NAME "ipv6calc"
-#define PROGRAM_VERSION "0.18"
+#define PROGRAM_VERSION "0.20"
 #define PROGRAM_COPYRIGHT "(P) & (C) 2001 by Peter Bieringer <pb@bieringer.de>\n published under GNU GPL"
 
 /* external functions */
@@ -104,6 +104,8 @@ typedef struct {
 extern int addr_to_ipv6addrstruct(char *addrstring, char *resultstring, ipv6calc_ipv6addr *ipv6addrp);
 
 extern int ipv6addrstruct_to_uncompaddr(ipv6calc_ipv6addr *ipv6addrp, char *resultstring);
+extern int ipv6addrstruct_to_uncompaddrprefix(ipv6calc_ipv6addr *ipv6addrp, char *resultstring);
+extern int ipv6addrstruct_to_uncompaddrsuffix(ipv6calc_ipv6addr *ipv6addrp, char *resultstring);
 
 extern int ipv6addrstruct_to_fulluncompaddr(ipv6calc_ipv6addr *ipv6addrp, char *resultstring);
 
