@@ -1,7 +1,7 @@
 /*
  * libipv6calc: Function libary for conversions
  *
- * Version:		$Id: libipv6calc.c,v 0.16 2001/03/13 $
+ * Version:		$Id: libipv6calc.c,v 0.20 2001/04/08 $
  * 
  * Author:		Peter Bieringer <pb@bieringer.de>
  *
@@ -215,6 +215,99 @@ int ipv6addrstruct_to_uncompaddr(ipv6calc_ipv6addr *ipv6addrp, char *resultstrin
 };
 
 
+/* function stores the prefix of an ipv6addr structure in an uncompressed IPv6 format string
+ *
+ * in:  ipv6addr = IPv6 address structure
+ * out: *resultstring = IPv6 address (modified)
+ * ret: ==0: ok, !=0: error
+ */
+int ipv6addrstruct_to_uncompaddrprefix(ipv6calc_ipv6addr *ipv6addrp, char *resultstring) {
+	int retval = 1;
+	int max, i;
+	char tempstring1[NI_MAXHOST], tempstring2[NI_MAXHOST];
+
+	/* test for misuse */
+	if ( ( ( ipv6addrp->scope & IPV6_ADDR_COMPATv4 ) || ( ipv6addrp->scope & IPV6_ADDR_MAPPED ) ) && ( ipv6addrp->prefixlength > 96 ) ) {
+		sprintf(resultstring, "Error, cannot print prefix of a compatv4/mapped address with prefix length bigger than 96!");
+		retval = 1;
+		return (retval);
+	};
+	if ( ipv6addrp->prefixlength == 0 ) {
+		sprintf(resultstring, "Error, cannot print prefix of a address with prefix length 0!");
+		retval = 1;
+		return (retval);
+	};
+   
+	max = ( ipv6addrp->prefixlength - 1 ) >> 4;
+	i = 0;
+	sprintf(tempstring1, "%s", "");
+	while (i <= max ) {
+		if ( i < max ) {
+			sprintf(tempstring2, "%s%x:", tempstring1, ipv6addrp->addr6[i]);
+		} else {
+			sprintf(tempstring2, "%s%x", tempstring1, ipv6addrp->addr6[i]);
+		};
+		i++;
+		sprintf(tempstring1, "%s", tempstring2);
+	};
+	sprintf(resultstring, "%s", tempstring1);
+
+#ifdef DEBUG_libipv6calc
+	fprintf(stderr, "libipv6calc/ipv6addrstruct_to_uncompaddrprefix: result string: %s\n", resultstring);
+#endif
+	retval = 0;
+	return (retval);
+};
+
+
+/* function stores the suffix of an ipv6addr structure in an uncompressed IPv6 format string
+ *
+ * in:  ipv6addr = IPv6 address structure
+ * out: *resultstring = IPv6 address (modified)
+ * ret: ==0: ok, !=0: error
+ */
+int ipv6addrstruct_to_uncompaddrsuffix(ipv6calc_ipv6addr *ipv6addrp, char *resultstring) {
+	int retval = 1;
+	int max, i;
+	char tempstring1[NI_MAXHOST], tempstring2[NI_MAXHOST];
+
+	/* test for misuse */
+	if ( ( ( ipv6addrp->scope & IPV6_ADDR_COMPATv4 ) || ( ipv6addrp->scope & IPV6_ADDR_MAPPED ) ) && ( ipv6addrp->prefixlength > 96 ) ) {
+		sprintf(resultstring, "Error, cannot print suffix of a compatv4/mapped address with prefix length bigger than 96!");
+		retval = 1;
+		return (retval);
+	};
+	if ( ipv6addrp->prefixlength == 128 ) {
+		sprintf(resultstring, "Error, cannot print suffix of a address with prefix length 128!");
+		retval = 1;
+		return (retval);
+	};
+   
+	max = 7;
+	i   = ipv6addrp->prefixlength >> 4;
+	sprintf(tempstring1, "%s", "");
+	while (i <= max ) {
+		if ( ( ( ipv6addrp->scope & IPV6_ADDR_COMPATv4 ) || ( ipv6addrp->scope & IPV6_ADDR_MAPPED ) ) && ( i == 6 ) ) {
+			sprintf(tempstring2, "%s%u.%u.%u.%u", tempstring1, ipv6addrp->addr6[6] >> 8, ipv6addrp->addr6[6] & 0xff, ipv6addrp->addr6[7] >> 8, ipv6addrp->addr6[7] & 0xff);
+			i = max;
+		} else if ( i < max ) {
+			sprintf(tempstring2, "%s%x:", tempstring1, ipv6addrp->addr6[i]);
+		} else {
+			sprintf(tempstring2, "%s%x", tempstring1, ipv6addrp->addr6[i]);
+		};
+		i++;
+		sprintf(tempstring1, "%s", tempstring2);
+	};
+	sprintf(resultstring, "%s", tempstring1);
+
+#ifdef DEBUG_libipv6calc
+	fprintf(stderr, "libipv6calc/ipv6addrstruct_to_uncompaddrsuffix: result string: %s\n", resultstring);
+#endif
+	retval = 0;
+	return (retval);
+};
+
+
 /* function stores the ipv6addr structure in an full uncompressed IPv6 format string
  *
  * in:  ipv6addr = IPv6 address structure
